[LON-CAPA-cvs] cvs: rat / lonratedt.pm lonratmenu.pm loncom/auth lonroles.pm loncom/homework lonhomework.pm structuretags.pm loncom/imspackages imsimport.pm loncom/publisher loncfile.pm loncleanup.pm lonconstruct.pm londiff.pm lonpubdir.pm lonpublisher.pm lonretrieve.pm lonrights.pm lonunauthorized.pm lonupload.pm testbankimport.pm loncom/xml londefdef.pm lonxml.pm

raeburn raeburn at source.lon-capa.org
Tue Jun 4 18:20:34 EDT 2013


raeburn		Tue Jun  4 22:20:34 2013 EDT

  Modified files:              
    /loncom/publisher	loncfile.pm loncleanup.pm lonconstruct.pm 
                     	londiff.pm lonpubdir.pm lonpublisher.pm 
                     	lonretrieve.pm lonrights.pm lonunauthorized.pm 
                     	lonupload.pm testbankimport.pm 
    /loncom/xml	londefdef.pm lonxml.pm 
    /loncom/homework	lonhomework.pm structuretags.pm 
    /loncom/imspackages	imsimport.pm 
    /loncom/auth	lonroles.pm 
    /rat	lonratedt.pm lonratmenu.pm 
  Log:
  - Replace term: "Construction Space" with "Authoring Space" for
    consistency with type of role used to access it, and action taken there.
  
  
-------------- next part --------------
Index: loncom/publisher/loncfile.pm
diff -u loncom/publisher/loncfile.pm:1.118 loncom/publisher/loncfile.pm:1.119
--- loncom/publisher/loncfile.pm:1.118	Thu Apr 11 14:59:58 2013
+++ loncom/publisher/loncfile.pm	Tue Jun  4 22:20:16 2013
@@ -9,7 +9,7 @@
 #  and displays a page showing the results of the action.
 #
 #
-# $Id: loncfile.pm,v 1.118 2013/04/11 14:59:58 bisitz Exp $
+# $Id: loncfile.pm,v 1.119 2013/06/04 22:20:16 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -37,7 +37,7 @@
 
 =head1 NAME
 
-Apache::loncfile - Construction space file management.
+Apache::loncfile - Authoring space file management.
 
 =head1 SYNOPSIS
  
@@ -1488,16 +1488,16 @@
     # Breadcrumbs
     &Apache::lonhtmlcommon::clear_breadcrumbs();
     &Apache::lonhtmlcommon::add_breadcrumb({
-        'text'  => 'Construction Space',
+        'text'  => 'Authoring Space',
         'href'  => &Apache::loncommon::authorspace($fn),
     });
     &Apache::lonhtmlcommon::add_breadcrumb({
         'text'  => 'File Operation',
-        'title' => 'Construction Space File Operation',
+        'title' => 'Authoring Space File Operation',
         'href'  => '',
     });
 
-    $r->print(&Apache::loncommon::start_page('Construction Space File Operation',
+    $r->print(&Apache::loncommon::start_page('Authoring Space File Operation',
 					     $js,
 					     {'add_entries' => \%loaditem,})
              .&Apache::lonhtmlcommon::breadcrumbs()
Index: loncom/publisher/loncleanup.pm
diff -u loncom/publisher/loncleanup.pm:1.19 loncom/publisher/loncleanup.pm:1.20
--- loncom/publisher/loncleanup.pm:1.19	Fri Dec 14 00:27:08 2012
+++ loncom/publisher/loncleanup.pm	Tue Jun  4 22:20:16 2013
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Handler to cleanup XML files
 #
-# $Id: loncleanup.pm,v 1.19 2012/12/14 00:27:08 raeburn Exp $
+# $Id: loncleanup.pm,v 1.20 2013/06/04 22:20:16 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -450,7 +450,7 @@
 
     # Breadcrumbs
     my $brcrum = [{'href' => &Apache::loncommon::authorspace($fn),
-                   'text' => 'Construction Space'},
+                   'text' => 'Authoring Space'},
                   {'href' => '',
                    'text' => 'Cleanup XML Document'}];
 
Index: loncom/publisher/lonconstruct.pm
diff -u loncom/publisher/lonconstruct.pm:1.37 loncom/publisher/lonconstruct.pm:1.38
--- loncom/publisher/lonconstruct.pm:1.37	Mon Apr 12 15:05:51 2010
+++ loncom/publisher/lonconstruct.pm	Tue Jun  4 22:20:16 2013
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
-# Construction Space Page Wrapper for Construction
+# Authoring Space Page Wrapper
 #
-# $Id: lonconstruct.pm,v 1.37 2010/04/12 15:05:51 droeschl Exp $
+# $Id: lonconstruct.pm,v 1.38 2013/06/04 22:20:16 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
Index: loncom/publisher/londiff.pm
diff -u loncom/publisher/londiff.pm:1.36 loncom/publisher/londiff.pm:1.37
--- loncom/publisher/londiff.pm:1.36	Mon Oct 29 17:38:55 2012
+++ loncom/publisher/londiff.pm	Tue Jun  4 22:20:16 2013
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Handler to show differences between file versions
 #
-# $Id: londiff.pm,v 1.36 2012/10/29 17:38:55 raeburn Exp $
+# $Id: londiff.pm,v 1.37 2013/06/04 22:20:16 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -144,9 +144,9 @@
                         ' ('.$cuname.':'.$cudom.')';
         $r->print('<p><span class="LC_info">');
         if ($env{'request.role'} =~ /^ca\./) {
-            $r->print(&mt('Co-Author in Construction Space for: [_1]',$nameshown));
+            $r->print(&mt('Co-Author in Authoring Space for: [_1]',$nameshown));
         } elsif ($env{'request.role'} =~ /^aa\./) {
-            $r->print(&mt('Assistant Author in Construction Space for: [_1]',$nameshown));
+            $r->print(&mt('Assistant Author in Authoring Space for: [_1]',$nameshown));
         } else {
             $r->print(&mt('Resource Author is: [_1]',$nameshown));
         }
@@ -159,7 +159,7 @@
 	if ($env{'form.versionone'} eq 'priv') {
 	    my $fn=$r->dir_config('lonDocRoot')."/priv/$cudom/$cuname".$efn;
 	    @f1=&get_split_file($fn,'local');
-	    $r->print('<b>'.&mt('Construction Space Version').'</b>');
+	    $r->print('<b>'.&mt('Authoring Space Version').'</b>');
 	} else {
 	    my $fn=$r->dir_config('lonDocRoot')."/res/$cudom/$cuname";
 	    if ($env{'form.versionone'}) {
@@ -188,7 +188,7 @@
 	} elsif ($env{'form.versiontwo'} eq 'priv') {
 	    my $fn=$r->dir_config('lonDocRoot')."/priv/$cudom/$cuname".$efn;
 	    @f2=&get_split_file($fn,'local');
-	    $r->print('<b>'.&mt('Construction Space Version').'</b>');
+	    $r->print('<b>'.&mt('Authoring Space Version').'</b>');
 	} else {
 	    my $fn=$r->dir_config('lonDocRoot')."/res/$cudom/$cuname/";
 	    if ($env{'form.versiontwo'}) {
Index: loncom/publisher/lonpublisher.pm
diff -u loncom/publisher/lonpublisher.pm:1.281 loncom/publisher/lonpublisher.pm:1.282
--- loncom/publisher/lonpublisher.pm:1.281	Tue Jan 15 18:21:31 2013
+++ loncom/publisher/lonpublisher.pm	Tue Jun  4 22:20:16 2013
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Publication Handler
 #
-# $Id: lonpublisher.pm,v 1.281 2013/01/15 18:21:31 raeburn Exp $
+# $Id: lonpublisher.pm,v 1.282 2013/06/04 22:20:16 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -2147,7 +2147,7 @@
     # Breadcrumbs
     &Apache::lonhtmlcommon::clear_breadcrumbs();
     &Apache::lonhtmlcommon::add_breadcrumb({
-        'text'  => 'Construction Space',
+        'text'  => 'Authoring Space',
         'href'  => &Apache::loncommon::authorspace($fn),
     });
     &Apache::lonhtmlcommon::add_breadcrumb({
Index: loncom/publisher/lonretrieve.pm
diff -u loncom/publisher/lonretrieve.pm:1.50 loncom/publisher/lonretrieve.pm:1.51
--- loncom/publisher/lonretrieve.pm:1.50	Wed Dec  5 16:57:29 2012
+++ loncom/publisher/lonretrieve.pm	Tue Jun  4 22:20:16 2013
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Handler to retrieve an old version of a file
 #
-# $Id: lonretrieve.pm,v 1.50 2012/12/05 16:57:29 bisitz Exp $
+# $Id: lonretrieve.pm,v 1.51 2013/06/04 22:20:16 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -318,7 +318,7 @@
     # Breadcrumbs
     &Apache::lonhtmlcommon::clear_breadcrumbs();
     &Apache::lonhtmlcommon::add_breadcrumb({
-        'text'  => 'Construction Space',
+        'text'  => 'Authoring Space',
         'href'  => &Apache::loncommon::authorspace($fn),
     });
     &Apache::lonhtmlcommon::add_breadcrumb({
Index: loncom/publisher/lonrights.pm
diff -u loncom/publisher/lonrights.pm:1.34 loncom/publisher/lonrights.pm:1.35
--- loncom/publisher/lonrights.pm:1.34	Fri Nov  9 15:29:19 2012
+++ loncom/publisher/lonrights.pm	Tue Jun  4 22:20:16 2013
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Handler to show and edit custom distribution rights
 #
-# $Id: lonrights.pm,v 1.34 2012/11/09 15:29:19 bisitz Exp $
+# $Id: lonrights.pm,v 1.35 2013/06/04 22:20:16 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -58,7 +58,7 @@
   # Breadcrumbs
   &Apache::lonhtmlcommon::clear_breadcrumbs();
   &Apache::lonhtmlcommon::add_breadcrumb({
-      'text'  => 'Construction Space',
+      'text'  => 'Authoring Space',
       'href'  => &Apache::loncommon::authorspace($r->uri),
       });
   &Apache::lonhtmlcommon::add_breadcrumb({
Index: loncom/publisher/lonunauthorized.pm
diff -u loncom/publisher/lonunauthorized.pm:1.15 loncom/publisher/lonunauthorized.pm:1.16
--- loncom/publisher/lonunauthorized.pm:1.15	Mon Oct 29 17:38:55 2012
+++ loncom/publisher/lonunauthorized.pm	Tue Jun  4 22:20:16 2013
@@ -1,7 +1,7 @@
 # The LearningOnline Network
 # Unauthorized to access construction space
 #
-# $Id: lonunauthorized.pm,v 1.15 2012/10/29 17:38:55 raeburn Exp $
+# $Id: lonunauthorized.pm,v 1.16 2013/06/04 22:20:16 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -55,7 +55,7 @@
     &Apache::lonhtmlcommon::clear_breadcrumbs();
     if ($env{'request.role'} =~ /^(au|ca|aa)/) { 
         &Apache::lonhtmlcommon::add_breadcrumb({
-            'text' => 'Construction Space',
+            'text' => 'Authoring Space',
             'href' => &Apache::loncommon::authorspace($env{'request.editurl'}),
         });
     } elsif (($env{'request.course.id'}) && 
@@ -67,7 +67,7 @@
     }
 
 # print header
-    $r->print(&Apache::loncommon::start_page("Failed Access to Construction Space",
+    $r->print(&Apache::loncommon::start_page("Failed Access to Authoring Space",
 					     undef,
 					     {'domain' => $ownerdomain,}).
                                              &Apache::lonhtmlcommon::breadcrumbs());
Index: loncom/publisher/lonupload.pm
diff -u loncom/publisher/lonupload.pm:1.61 loncom/publisher/lonupload.pm:1.62
--- loncom/publisher/lonupload.pm:1.61	Mon Oct 29 17:38:55 2012
+++ loncom/publisher/lonupload.pm	Tue Jun  4 22:20:16 2013
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Handler to upload files into construction space
 #
-# $Id: lonupload.pm,v 1.61 2012/10/29 17:38:55 raeburn Exp $
+# $Id: lonupload.pm,v 1.62 2013/06/04 22:20:16 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -518,10 +518,10 @@
 
     # Breadcrumbs
     my $brcrum = [{'href' => &Apache::loncommon::authorspace($fn),
-                   'text' => 'Construction Space'},
+                   'text' => 'Authoring Space'},
                   {'href' => '/adm/upload',
-                   'text' => 'Upload file to Construction Space'}];
-    $r->print(&Apache::loncommon::start_page('Upload file to Construction Space',
+                   'text' => 'Upload file to Authoring Space'}];
+    $r->print(&Apache::loncommon::start_page('Upload file to Authoring Space',
                                              $javascript,
                                              {'bread_crumbs' => $brcrum,})
              .&Apache::loncommon::head_subbox(
Index: loncom/publisher/testbankimport.pm
diff -u loncom/publisher/testbankimport.pm:1.38 loncom/publisher/testbankimport.pm:1.39
--- loncom/publisher/testbankimport.pm:1.38	Thu Apr 11 14:59:58 2013
+++ loncom/publisher/testbankimport.pm	Tue Jun  4 22:20:16 2013
@@ -1,5 +1,5 @@
 # Handler for parsing text upload problem descriptions into .problems
-# $Id: testbankimport.pm,v 1.38 2013/04/11 14:59:58 bisitz Exp $
+# $Id: testbankimport.pm,v 1.39 2013/06/04 22:20:16 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1776,7 +1776,7 @@
     my ($uname,$udom,$javascript,$loadentries,$title,$current_page,$pagesref,
         $namesref) = @_;
     my $brcrum = [{'href' => &Apache::loncommon::authorspace("/priv/$udom/$uname/"),
-                   'text' => 'Construction Space'}];
+                   'text' => 'Authoring Space'}];
     if ($env{'form.phase'} eq 'three') {
         if (ref($pagesref) eq 'ARRAY') {
             for (my $i=0; $i<$current_page; $i++) {
@@ -1838,7 +1838,7 @@
     my $page_name = '';
     my $current_page = '';
     my $qcount = '';
-    my $title = 'Upload testbank questions to Construction Space';
+    my $title = 'Upload testbank questions to Authoring Space';
 
 # ----------------------------------------------------------- Start page output
     &Apache::loncommon::content_type($r,'text/html');
Index: loncom/xml/londefdef.pm
diff -u loncom/xml/londefdef.pm:1.443 loncom/xml/londefdef.pm:1.444
--- loncom/xml/londefdef.pm:1.443	Sun May  5 00:10:16 2013
+++ loncom/xml/londefdef.pm	Tue Jun  4 22:20:20 2013
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Tags Default Definition Module 
 #
-# $Id: londefdef.pm,v 1.443 2013/05/05 00:10:16 raeburn Exp $
+# $Id: londefdef.pm,v 1.444 2013/06/04 22:20:20 raeburn Exp $
 # 
 #
 # Copyright Michigan State University Board of Trustees
@@ -572,7 +572,7 @@
     if ($env{'request.state'} eq 'construct') {
         my $url=&Apache::lonnet::hreflocation('',$env{'request.filename'});
         &Apache::lonhtmlcommon::add_breadcrumb({
-            'text'  => 'Construction Space',
+            'text'  => 'Authoring Space',
             'href'  => &Apache::loncommon::authorspace($url),
         });
         &Apache::lonhtmlcommon::add_breadcrumb({
Index: loncom/xml/lonxml.pm
diff -u loncom/xml/lonxml.pm:1.540 loncom/xml/lonxml.pm:1.541
--- loncom/xml/lonxml.pm:1.540	Sun May 12 13:05:31 2013
+++ loncom/xml/lonxml.pm	Tue Jun  4 22:20:20 2013
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # XML Parser Module 
 #
-# $Id: lonxml.pm,v 1.540 2013/05/12 13:05:31 raeburn Exp $
+# $Id: lonxml.pm,v 1.541 2013/06/04 22:20:20 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -1811,7 +1811,7 @@
                 my $brcrum;
                 if ($env{'request.state'} eq 'construct') {
                     $brcrum = [{'href' => &Apache::loncommon::authorspace($request->uri),
-                                'text' => 'Construction Space'},
+                                'text' => 'Authoring Space'},
                                {'href' => '',
                                 'text' => $breadcrumbtext}];
                 } else {
@@ -1873,7 +1873,7 @@
             if ($env{'request.state'} eq 'construct') {
                 $options{'bread_crumbs'} = [{
                             'href' => &Apache::loncommon::authorspace($request->uri),
-                            'text' => 'Construction Space'},
+                            'text' => 'Authoring Space'},
                            {'href' => '',
                             'text' => $breadcrumbtext}];
                 $header = &Apache::loncommon::head_subbox(
@@ -1908,7 +1908,7 @@
 	    $title = substr($title, rindex($title, '/') + 1);
 	}
         $result = "<script type='text/javascript'>top.document.title = '$title - LON-CAPA "
-                  .&mt('Construction Space')."';</script>";
+                  .&mt('Authoring Space')."';</script>";
     }
     return $result;
 }
Index: loncom/imspackages/imsimport.pm
diff -u loncom/imspackages/imsimport.pm:1.38 loncom/imspackages/imsimport.pm:1.39
--- loncom/imspackages/imsimport.pm:1.38	Mon Oct 29 17:38:59 2012
+++ loncom/imspackages/imsimport.pm	Tue Jun  4 22:20:28 2013
@@ -1,6 +1,6 @@
 # The LearningOnline Network with CAPA
 # 
-# $Id: imsimport.pm,v 1.38 2012/10/29 17:38:59 raeburn Exp $
+# $Id: imsimport.pm,v 1.39 2013/06/04 22:20:28 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -536,7 +536,7 @@
                  yims => 'Your IMS package has been processed successfully.',
                  plsv => 'Please view the imported items and use the LON-CAPA editing tools to make changes.',
                  tseq => "The sequences directory contains a file named 'Top.sequence' which includes links to the items found at the top level of your IMS package. From there you can follow links to display all the imported items. Alternatively, you can browse the pages, sequences, problems and resfiles directories directly. Note if you rename a file, you will need to modify any .sequence files or .page files which include a reference to the renamed file.",
-                 tfin => 'The final step in the IMS import process is to publish the materials you have imported into your Construction Space so that you can use them in a course. Once your files are published, subsequent re-publication will result in the storage of information about changes between the different versions.',
+                 tfin => 'The final step in the IMS import process is to publish the materials you have imported into your Authoring Space so that you can use them in a course. Once your files are published, subsequent re-publication will result in the storage of information about changes between the different versions.',
                  disp => 'Display new directory',
                  proc => 'Processing of your IMS package failed, because the IMS content package did not contain an IMS manifest file.'
              );
@@ -726,7 +726,7 @@
 END_JS
     }
 
-    my $title = 'Upload IMS package to Construction Space';
+    my $title = 'Upload IMS package to Authoring Space';
     $r->print(&Apache::loncommon::start_page($title, $javascript));
 
     if (($uname ne $env{'user.name'}) || ($udom ne $env{'user.domain'})) {
Index: loncom/auth/lonroles.pm
diff -u loncom/auth/lonroles.pm:1.287 loncom/auth/lonroles.pm:1.288
--- loncom/auth/lonroles.pm:1.287	Sun Jun  2 02:21:43 2013
+++ loncom/auth/lonroles.pm	Tue Jun  4 22:20:31 2013
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # User Roles Screen
 #
-# $Id: lonroles.pm,v 1.287 2013/06/02 02:21:43 raeburn Exp $
+# $Id: lonroles.pm,v 1.288 2013/06/04 22:20:31 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -691,7 +691,7 @@
                             $redirect_url .= $where;
                         }
                         $redirect_url .= '/';
-                        &redirect_user($r,&mt('Entering Construction Space'),
+                        &redirect_user($r,&mt('Entering Authoring Space'),
                                        $redirect_url);
                         return OK;
                     }
@@ -1156,7 +1156,7 @@
                     }
                     #next if ($home eq 'no_host');
                     $home = &Apache::lonnet::hostname($home);
-                    $ttype='Construction Space';
+                    $ttype='Authoring Space';
                     $twhere=&mt('User').': '.$trest.'<br />'.&mt('Domain').
                         ': '.$tdom.'<br />'.
                         ' '.&mt('Server').': '.$home;
@@ -1175,7 +1175,7 @@
                     }
                     #next if ($home eq 'no_host');
                     $home = &Apache::lonnet::hostname($home);
-                    $ttype='Construction Space';
+                    $ttype='Authoring Space';
                     $twhere=&mt('Domain').': '.$tdom.'<br />'.&mt('Server').
                         ': '.$home;
                     $env{'course.'.$tdom.'_'.$trest.'.description'}='ca';
@@ -1348,7 +1348,7 @@
 }
 
 sub roletypes {
-    my @types = ('Domain','Construction Space','Course','Community','Unavailable','System');
+    my @types = ('Domain','Authoring Space','Course','Community','Unavailable','System');
     return @types; 
 }
 
@@ -1487,7 +1487,7 @@
 	my (undef,$tdom,$trest,$tsec)=split(m{/},$where);
 	if ($trest) {
 	    if ($env{'course.'.$tdom.'_'.$trest.'.description'} eq 'ca') {
-		$ttype='Construction Space';
+		$ttype='Authoring Space';
 		$twhere='User: '.$trest.', Domain: '.$tdom;
 	    } else {
 		$ttype= &Apache::loncommon::course_type($tdom.'_'.$trest);
Index: rat/lonratedt.pm
diff -u rat/lonratedt.pm:1.107 rat/lonratedt.pm:1.108
--- rat/lonratedt.pm:1.107	Sun Dec 16 16:10:25 2012
+++ rat/lonratedt.pm	Tue Jun  4 22:20:34 2013
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Edit Handler for RAT Maps
 #
-# $Id: lonratedt.pm,v 1.107 2012/12/16 16:10:25 raeburn Exp $
+# $Id: lonratedt.pm,v 1.108 2013/06/04 22:20:34 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -548,7 +548,7 @@
 
     &Apache::lonhtmlcommon::clear_breadcrumbs();
     &Apache::lonhtmlcommon::add_breadcrumb({
-        text  => 'Construction Space',
+        text  => 'Authoring Space',
         href  => &Apache::loncommon::authorspace($url),
         faq   => 6,
         bug   => 'RAT',
@@ -563,7 +563,7 @@
         href  => '',});
 
     # Breadcrumbs are included by &start_page
-    my $start_page = &Apache::loncommon::start_page('Construction Space',$js)
+    my $start_page = &Apache::loncommon::start_page('Authoring Space',$js)
                     .&Apache::loncommon::head_subbox(
                          &Apache::loncommon::CSTR_pageheader()
                         .&buttons(2));
@@ -649,10 +649,10 @@
    my ($path) = ($dir =~ m{^\Q$londocroot\E?(/priv/[^/]+/[^/]+/)});
    $dir=~s{^\Q$londocroot/priv/\E[^/]+/[^/]+}{};
    my $brcrum = [{'href' => &Apache::loncommon::authorspace($path),
-                  'text' => 'Construction Space'}];
+                  'text' => 'Authoring Space'}];
 #                 {'href' => '',
 #                  'text' => 'No such directory'}];
-   $r->print(&Apache::loncommon::start_page('Construction Space',
+   $r->print(&Apache::loncommon::start_page('Authoring Space',
                                             undef,
                                             {'bread_crumbs' => $brcrum,})
             .&Apache::loncommon::head_subbox(
@@ -671,7 +671,7 @@
 
     &Apache::lonhtmlcommon::clear_breadcrumbs();
     &Apache::lonhtmlcommon::add_breadcrumb({
-        text  => 'Construction Space',
+        text  => 'Authoring Space',
         href  => &Apache::loncommon::authorspace($url),
         faq   => 6,
         bug   => 'RAT',
@@ -708,7 +708,7 @@
              .'<th>'.&mt('Title in map').'</th>'
              .'<th>'.&mt('Filename of resource').'</th>'
              .'<th>'.&mt('Link to published resource').'</th>'
-             .'<th>'.&mt('Link to resource in Construction Space').'</th>'
+             .'<th>'.&mt('Link to resource in Authoring Space').'</th>'
              .&Apache::loncommon::end_data_table_header_row()
     );
     foreach (&LONCAPA::map::attemptread(&Apache::lonnet::filelocation('',$url))) {
@@ -746,7 +746,7 @@
             $r->print('</td><td>');
             if ($url) {
                $r->print('<a href="'.$cstrurl.'">'.
-                         &mt('Construction space').'</a>');
+                         &mt('Authoring space').'</a>');
             } else {
                 $r->print(' ');
             }
Index: rat/lonratmenu.pm
diff -u rat/lonratmenu.pm:1.19 rat/lonratmenu.pm:1.20
--- rat/lonratmenu.pm:1.19	Tue May 15 01:41:42 2012
+++ rat/lonratmenu.pm	Tue Jun  4 22:20:34 2013
@@ -2,7 +2,7 @@
 # Build menu bar for Advanced RAT. Uses javascript code originally in
 # static file: rat/client/code.html, now in  rat/client/ratcode.js  
 #
-# $Id: lonratmenu.pm,v 1.19 2012/05/15 01:41:42 raeburn Exp $
+# $Id: lonratmenu.pm,v 1.20 2013/06/04 22:20:34 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -48,7 +48,7 @@
 
     # Breadcrumbs
     my $brcrum = [{'href' => &Apache::loncommon::authorspace($r->uri),
-                   'text' => 'Construction Space'},
+                   'text' => 'Authoring Space'},
                   {'href' => '',
                    'text' => 'RAT'},
                   {'href' => '',


More information about the LON-CAPA-cvs mailing list
Index: loncom/publisher/lonpubdir.pm
diff -u loncom/publisher/lonpubdir.pm:1.144 loncom/publisher/lonpubdir.pm:1.145
--- loncom/publisher/lonpubdir.pm:1.144	Mon Oct 29 17:38:55 2012
+++ loncom/publisher/lonpubdir.pm	Tue Jun  4 22:20:16 2013
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # Construction Space Directory Lister
 #
-# $Id: lonpubdir.pm,v 1.144 2012/10/29 17:38:55 raeburn Exp $
+# $Id: lonpubdir.pm,v 1.145 2013/06/04 22:20:16 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -143,20 +143,20 @@
 
     &Apache::lonhtmlcommon::clear_breadcrumbs();
     &Apache::lonhtmlcommon::add_breadcrumb({
-        'text'  => 'Construction Space',
+        'text'  => 'Authoring Space',
         'href'  => &Apache::loncommon::authorspace($formaction),
     });
     # breadcrumbs (and tools) will be created 
     # in start_page->bodytag->innerregister
 
     $env{'request.noversionuri'}=$formaction;
-    $r->print(&Apache::loncommon::start_page('Construction Space',undef));
+    $r->print(&Apache::loncommon::start_page('Authoring Space',undef));
 
     $r->print(&Apache::loncommon::head_subbox(
                 &Apache::loncommon::CSTR_pageheader()));
 
     my $esc_thisdisfn = &Apache::loncommon::escape_single($thisdisfn);
-    my $doctitle = 'LON-CAPA '.&mt('Construction Space');
+    my $doctitle = 'LON-CAPA '.&mt('Authoring Space');
     my $newname = &mt('New Name');
     my $pubdirscript=(<<ENDPUBDIRSCRIPT);
 <script type="text/javascript">
@@ -706,7 +706,7 @@
 
 =head1 NAME
 
-Apache::lonpubdir - Construction space directory lister
+Apache::lonpubdir - Authoring space directory lister
 
 =head1 SYNOPSIS
 
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
-# Construction Space Directory Lister
+# Authoring Space Directory Lister
 #
Index: loncom/homework/lonhomework.pm
diff -u loncom/homework/lonhomework.pm:1.337 loncom/homework/lonhomework.pm:1.338
--- loncom/homework/lonhomework.pm:1.337	Mon Apr  1 21:40:14 2013
+++ loncom/homework/lonhomework.pm	Tue Jun  4 22:20:24 2013
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA
 # The LON-CAPA Homework handler
 #
-# $Id: lonhomework.pm,v 1.337 2013/04/01 21:40:14 raeburn Exp $
+# $Id: lonhomework.pm,v 1.338 2013/06/04 22:20:24 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -163,7 +163,7 @@
 	    }
         }
 #
 # End of Construction Space
 #
     }
 #
@@ -669,7 +669,7 @@
 }
 
 sub handle_save_or_undo {
-    my ($request,$problem,$result) = @_;
+    my ($request,$problem,$result,$getobjref) = @_;
 
     my $file    = &Apache::lonnet::filelocation("",$request->uri);
     my $filebak =$file.".bak";
@@ -712,6 +712,30 @@
 	my $fh=Apache::File->new(">$file");
 	if (defined($fh)) {
 	    print $fh $$result;
+            if (ref($getobjref) eq 'SCALAR') {
+                if ($file =~ m{([^/]+)\.(html?)$}) {
+                    my $fname = $1;
+                    my $ext = $2;
+                    my $path = $file;
+                    $path =~ s/\Q$fname\E\.\Q$ext\E$//; 
+                    my (%allfiles,%codebase);
+                    &Apache::lonnet::extract_embedded_items($file,\%allfiles,
+                                                           \%codebase,$result);
+                    if (keys(%allfiles) > 0) {
+                        my $url = $request->uri;
+                        my $state = <<STATE;
+    <input type="hidden" name="action" value="upload_embedded" />
+    <input type="hidden" name="url" value="$url" />
+STATE
+                        $$getobjref = "<h3>".&mt("Reference Warning")."</h3>".
+                                      "<p>".&mt("Completed upload of the file. This file contained references to other files.")."</p>".
+                                      "<p>".&mt("Please select the locations from which the referenced files are to be uploaded.")."</p>".
+                                      &Apache::loncommon::ask_for_embedded_content($url,$state,\%allfiles,\%codebase,
+                                      {'error_on_invalid_names'   => 1,
+                                       'ignore_remote_references' => 1,});
+                    }
+                }
+            }
 	} else {
 	    &Apache::lonxml::info('<span class="LC_error">'.
 				  &mt("Unable to write to [_1]",
@@ -730,7 +754,7 @@
 
     # Breadcrumbs
     my $brcrum = [{'href' => &Apache::loncommon::authorspace($request->uri),
-                   'text' => 'Construction Space'},
+                   'text' => 'Authoring Space'},
                   {'href' => '',
                    'text' => 'Problem Testing'},
                   {'href' => '',
@@ -964,7 +988,7 @@
 
     # Breadcrumbs
     my $brcrum = [{'href' => &Apache::loncommon::authorspace($request->uri),
-                   'text' => 'Construction Space'},
+                   'text' => 'Authoring Space'},
                   {'href' => '',
                    'text' => 'Problem Editing'}];
 
@@ -1190,7 +1214,7 @@
 	my $errormsg;
 	my $instructions;
         my $brcrum = [{'href' => &Apache::loncommon::authorspace($request->uri),
-                       'text' => 'Construction Space'},
+                       'text' => 'Authoring Space'},
                       {'href' => '',
                        'text' => "Create New $extension"}];
 	my $start_page = 
@@ -163,7 +163,7 @@
         }
 #
-# End of Construction Space
+# End of Authoring Space
 #
     }
Index: loncom/homework/structuretags.pm
diff -u loncom/homework/structuretags.pm:1.512 loncom/homework/structuretags.pm:1.513
--- loncom/homework/structuretags.pm:1.512	Fri May  3 15:38:52 2013
+++ loncom/homework/structuretags.pm	Tue Jun  4 22:20:24 2013
@@ -1,7 +1,7 @@
 # The LearningOnline Network with CAPA 
 # definition of tags that give a structure to a document
 #
-# $Id: structuretags.pm,v 1.512 2013/05/03 15:38:52 bisitz Exp $
+# $Id: structuretags.pm,v 1.513 2013/06/04 22:20:24 raeburn Exp $
 #
 # Copyright Michigan State University Board of Trustees
 #
@@ -379,10 +379,10 @@
     } elsif (!defined($found{'body'}) 
 	     && $env{'request.state'} eq 'construct') {
 	if ($target eq 'web' || $target eq 'edit') {
         # Breadcrumbs for Construction Space
         &Apache::lonhtmlcommon::clear_breadcrumbs();
         &Apache::lonhtmlcommon::add_breadcrumb({
-            'text'  => 'Construction Space',
+            'text'  => 'Authoring Space',
             'href'  => &Apache::loncommon::authorspace($env{'request.uri'}),
         });
         # breadcrumbs (and tools) will be created 
@@ -379,10 +379,10 @@
 	     && $env{'request.state'} eq 'construct') {
 	if ($target eq 'web' || $target eq 'edit') {
-        # Breadcrumbs for Construction Space
+        # Breadcrumbs for Authoring Space
         &Apache::lonhtmlcommon::clear_breadcrumbs();
         &Apache::lonhtmlcommon::add_breadcrumb({